@@ -5,7 +5,7 @@ import click
 
 from datetime import datetime
 from functools import wraps
-from typing import Callable, List, Optional
+from typing import Any, Callable, List, Optional
 
 from ..constants import DEFAULT_QUERY_TIMEOUT
 from ..models import CacheMode, PercentChange, INF, NEGATIVE_ONE, DEFAULT_LIMIT, TimeGranularity
@@ -232,14 +232,14 @@ def get_query_logs_url_for_id(query_id: str) -> str:
     return f"https://app.transformdata.io/mql/query/{query_id}?tab=server_logs"
 
 
-def exception_handler(func):
+def exception_handler(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[misc]
     """Decorator to handle exceptions
 
     TODO: handle custom exceptions
     """
 
     @wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args, **kwargs):  # type: ignore
         try:
             func(*args, **kwargs)
         except Exception as e:
