@@ -287,6 +287,12 @@ def health_report(config: CLIContext) -> None:
     default=False,
     help="In the query output, show the query that was executed against the data warehouse",
 )
+@click.option(
+    "--decimals",
+    required=False,
+    default=2,
+    help="Choose the number of decimal places to round for the numerical values",
+)
 @query_observability_options
 @exception_handler
 def query(
@@ -307,6 +313,7 @@ def query(
     as_table: Optional[str] = None,
     csv: Optional[click.utils.LazyFile] = None,
     explain: bool = False,
+    decimals: int = 2,
     web: bool = False,
     debug: bool = False,
     allow_dynamic_cache: bool = True,
@@ -375,11 +382,11 @@ def query(
             df.to_csv(csv, index=False)
             click.echo(f"Successfully written query output to {csv.name}")
         else:
-            # NOTE: remove `to_string` if no pandas dependency is < 1.0.0
-            if parse(pd.__version__) >= parse("1.0.0"):
-                click.echo(df.to_markdown(index=False, floatfmt=".2f"))
+            # NOTE: remove `to_string` if no pandas dependency is < 1.1.0
+            if parse(pd.__version__) >= parse("1.1.0"):
+                click.echo(df.to_markdown(index=False, floatfmt=f".{decimals}f"))
             else:
-                click.echo(df.to_string(index=False, float_format=lambda x: format(x, ".2f")))
+                click.echo(df.to_string(index=False, float_format=lambda x: format(x, f".{decimals}f")))
 
     if web:
         click.launch(get_query_logs_url_for_id(query_id))
